-
-
-
\ No newline at end of file
diff --git a/configs/Square.xml b/configs/iBoxPay.xml
similarity index 99%
rename from configs/Square.xml
rename to configs/iBoxPay.xml
index bf3cec9..acc6894 100644
--- a/configs/Square.xml
+++ b/configs/iBoxPay.xml
@@ -1,5 +1,5 @@
-
+
@@ -111,7 +111,7 @@
-
+
diff --git a/install.sh b/install.sh
index a461c00..ce273df 100755
--- a/install.sh
+++ b/install.sh
@@ -1,7 +1,7 @@
#!/bin/bash
-# Installs Square's IntelliJ configs into your user configs.
+# Installs iBoxPay's IntelliJ configs into your user configs.
-echo "Installing Square code style configs..."
+echo "Installing iBoxPay code style configs..."
for i in $HOME/Library/Preferences/IntelliJIdea*/codestyles \
$HOME/Library/Preferences/IdeaIC*/codestyles \
@@ -15,4 +15,4 @@ done
echo "Done."
echo ""
-echo "Restart IntelliJ and/or AndroidStudio, go to preferences, and apply 'Square' or 'SquareAndroid'."
+echo "Restart IntelliJ and/or AndroidStudio, go to preferences, and apply 'iBoxPay' or 'AndroidStyle'."